clear all
set more off

* directory
gl main "C:\WBG\github\RR_LAC_2024_152\v2"
global wave1 "$main\Data\Wave 1"
global wave2 "$main\Data\Wave 2"

sysdir set PLUS "$main\ado"
set varabbrev on

ssc install outreg2, replace
ssc install estout, replace
log using reppackage_152, replace
/*==================================================
          APPENDING COUNTRY DATASETS
==================================================*/

*Make the Suriname dataset compliant with the other countries
use "$wave2/SRN_cases_with_weights_v2.dta", clear
rename w_hh w_hh_ph2w2
rename w_ind w_ind_ph2w2
rename num_children num_hijos
save "$wave2/597_ph2w2_casos_library.dta", replace

*Destring variables: Wave 2
foreach x in 501 509 597 758 767 {
	use "$wave2/`x'_ph2w2_casos_library.dta", clear
	destring folio, replace
	recast double folio
	save "$wave2/temp_`x'.dta", replace
}

* Append datasets: Wave 2
use "$wave2/temp_767.dta", clear
foreach x in 501 509 597 758 {
    append using "$wave2/temp_`x'.dta", force
	erase "$wave2/temp_`x'.dta"
}
save "$wave2/carib_ph2_2_complete.dta", replace

*Destring variables: Wave 1
foreach x in 501 509 758 767{
	use "$wave1/`x'_casos_clean.dta", clear
	destring folio, replace
	recast double folio
	save "$wave1/temp_`x'.dta", replace
}

* Append datasets: Wave 1
use "$wave1/temp_767.dta", clear
foreach x in 501 509 758{
    append using "$wave1/temp_`x'.dta"
	erase "$wave1/temp_`x'.dta"
}
save "$wave1/carib_ph2_1_complete.dta", replace

* Merge specific sections from Wave 1 to Wave 2 aggregate dataset
use "$wave1/carib_ph2_1_complete.dta", clear
rename (u04* u02* u03* u05* u06* u07* u09* u12*) (x04* x02* x03* x05* x06* x07* x09* x12*)
save "$wave1/carib_ph2_1_complete.dta", replace
use "$wave2/carib_ph2_2_complete.dta", replace
sort folio
merge 1:1 folio using "$wave1/carib_ph2_1_complete.dta", keepusing(x04_04 x02* x03* x05* x06* x07* x09* x12*)
tab pais tipo_muestra if _merge == 3, m	
drop if	_merge == 2
drop _merge

recode pais .=597
drop if pais==876|pais==592
la def pais 509"Haiti" 501"Belize" 758"Saint Lucia" 767"Dominica" 597"Suriname", modify
la val pais pais

/*================================================
     RECODING OF DISASTER RISK MANAGEMENT MODULE
==================================================*/

* dis3a. Do you think your household is threatened by Extreme rainfall? (% Yes)
gen dis3a = 0 if (v15_03a!=1 & v15_03a!=98 & v15_03a!=.)
replace dis3a = 0 if (u15_03a!=1 & u15_03a!=98 & u15_03a!=.)
replace dis3a = 1 if v15_03a==1
replace dis3a = 1 if u15_03a==1
label variable dis3a "Extreme rainfall"

* dis3b. Do you think your household is threatened by Severe storms? (% Yes)
gen dis3b = 0 if (v15_03b!=1 & v15_03b!=98 & v15_03b!=.)
replace dis3b = 1 if v15_03b==1
label variable dis3b "Severe storms"

* dis3c. Do you think your household is threatened by floods? (% Yes)
gen dis3c = 0 if (v15_03c!=1 & v15_03c!=98 & v15_03c!=.)
replace dis3c = 0 if (u15_03b!=1 & u15_03b!=98 & u15_03b!=.)
replace dis3c = 1 if v15_03c==1
replace dis3c = 1 if u15_03b==1
label variable dis3c "Floods"

* dis3d. Do you think your household is threatened by Tropical cyclones / hurricanes? (% Yes)
gen dis3d = 0 if (v15_03d!=1 & v15_03d!=98 & v15_03d!=.)
replace dis3d = 1 if v15_03d==1
label variable dis3d "Tropical cyclones/Hurricanes"

* dis3e. Do you think your household is threatened by Heat waves? (% Yes)
gen dis3e = 0 if (v15_03e!=1 & v15_03e!=98 & v15_03e!=.)
replace dis3e = 1 if v15_03e==1
label variable dis3e "Heat waves"

* dis3f. Do you think your household is threatened by Drought? (% Yes)
gen dis3f = 0 if (v15_03f!=1 & v15_03f!=98 & v15_03f!=.)
replace dis3f = 0 if (u15_03c!=1 & u15_03c!=98 & u15_03c!=.)
replace dis3f = 1 if v15_03f==1
replace dis3f = 1 if u15_03c==1
label variable dis3f "Drought"

* dis3g. Do you think your household is threatened by Wildfires? (% Yes)
gen dis3g = 0 if (v15_03g!=1 & v15_03g!=98 & v15_03g!=.)
replace dis3g = 1 if v15_03g==1
label variable dis3g "Wildfires"

* dis3h. Do you think your household is threatened by Volcanic eruption? (% Yes)
gen dis3h = 0 if (v15_03h!=1 & v15_03h!=98 & v15_03h!=.)
replace dis3h = 1 if v15_03h==1
label variable dis3h "Volcanic eruptions"

* dis3i. Do you think your household is threatened by Earthquake? (% Yes)
gen dis3i = 0 if (v15_03i!=1 & v15_03i!=98 & v15_03i!=.)
replace dis3i = 0 if (u15_03d!=1 & u15_03d!=98 & u15_03d!=.)
replace dis3i = 1 if v15_03i==1
replace dis3i = 1 if u15_03d==1
label variable dis3i "Earthquake"

* dis3j. Do you think your household is threatened by Landslides? (% Yes)
gen dis3j = 0 if (v15_03j!=1 & v15_03j!=98 & v15_03j!=.)
replace dis3j = 1 if v15_03j==1
label variable dis3j "Landslides"

* dis3k. Do you think your household is threatened by High sea swells? (% Yes)
gen dis3k = 0 if (v15_03k!=1 & v15_03k!=98 & v15_03k!=.)
replace dis3k = 1 if v15_03k==1
label variable dis3k "High sea swells"

* dis3l. Do you think your household is threatened by Tsunami? (% Yes)
gen dis3l = 0 if (v15_03l!=1 & v15_03l!=98 & v15_03l!=.)
replace dis3l = 1 if v15_03l==1
label variable dis3l "Tsunami"

* dis3m. Do you think your household is threatened by Other (% Yes)
gen dis3m = 0 if (v15_03m!=1 & v15_03m!=98 & v15_03m!=.)
replace dis3m = 0 if (u15_03e!=1 & u15_03e!=98 & u15_03e!=.)
replace dis3m = 1 if v15_03m==1
replace dis3m = 1 if u15_03e==1
label variable dis3m "Other"

* dis4a. Do you feel like your household is very prepared, somewhat prepared, or not prepared to handle a disaster or emergency at the moment ? (% Very prepared)
gen dis4a = 0 if (v15_04!=1 & v15_04!=98 & v15_04!=.)
replace dis4a = 0 if (u15_04!=1 & u15_04!=98 & u15_04!=.)
replace dis4a = 1 if v15_04==1
replace dis4a = 1 if u15_04==1
label variable dis4a "Very prepared"

* dis4b. Do you feel like your household is very prepared, somewhat prepared, or not prepared to handle a disaster or emergency at the moment ? (% Somewhat prepared)
gen dis4b = 0 if (v15_04!=2 & v15_04!=98 & v15_04!=.)
replace dis4b = 0 if (u15_04!=2 & u15_04!=98 & u15_04!=.)
replace dis4b = 1 if v15_04==2
replace dis4b = 1 if u15_04==2
label variable dis4b "Somewhat prepared"

* dis4c. Do you feel like your household is very prepared, somewhat prepared, or not prepared to handle a disaster or emergency at the moment ? (% Not prepared)
gen dis4c = 0 if (v15_04!=3 & v15_04!=98 & v15_04!=.)
replace dis4c = 0 if (u15_04!=3 & u15_04!=98 & u15_04!=.)
replace dis4c = 1 if v15_04==3
replace dis4c = 1 if u15_04==3
label variable dis4c "Not prepared"

* HH is prepared (very or somewhat) to handle a disaster or emergency at the moment 
gen prepared=0 if dis4a!=.&dis4b!=.&dis4c!=.
replace prepared=1 if dis4a==1|dis4b==1
label variable prepared "Household is prepared"

* dis5.  Do you have supplies or other things in your home that could be used to help your household in a disaster or emergency? (% Yes)
gen dis5 = 0 if (v15_05!=1 & v15_05!=98 & v15_05!=.)
replace dis5 = 0 if (u15_05!=1 & u15_05!=98 & u15_05!=.)
replace dis5 = 1 if v15_05==1
replace dis5 = 1 if u15_05==1
label variable dis5 "Any supply"

* dis6a.  What supplies do you have?  (% Packaged food)
gen dis6a = 0 if dis5==1 & (v15_06a!=1 & v15_06a!=98 & v15_06a!=.)
replace dis6a = 0 if dis5==1 
replace dis6a = 1 if dis5==1 &v15_06a==1
replace dis6a = 1 if dis5==1 & (u15_06a=="a"|u15_06b=="a"|u15_06c=="a"|u15_06d=="a"|u15_06e=="a"|u15_06f=="a"|u15_06g=="a"|u15_06h=="a"|u15_06i=="a"|u15_06j=="a"|u15_06k=="a"|u15_06l=="a"|u15_06m=="a")
label variable dis6a "Packaged food"

* dis6b.  What supplies do you have?  (% Bottled water)
gen dis6b = 0 if dis5==1&(v15_06b!=1 & v15_06b!=98 & v15_06b!=.)
replace dis6b = 0 if dis5==1
replace dis6b = 1 if dis5==1&v15_06b==1
replace dis6b = 1 if dis5==1 & (u15_06a=="b"|u15_06b=="b"|u15_06c=="b"|u15_06d=="b"|u15_06e=="b"|u15_06f=="b"|u15_06g=="b"|u15_06h=="b"|u15_06i=="b"|u15_06j=="b"|u15_06k=="b"|u15_06l=="b"|u15_06m=="b")
label variable dis6b "Bottled water"

* dis6c.  What supplies do you have?  (% Battery powered radio)
gen dis6c = 0 if dis5==1&(v15_06c!=1 & v15_06c!=98 & v15_06c!=.)
replace dis6c = 0 if dis5==1
replace dis6c = 1 if dis5==1&v15_06c==1
replace dis6c = 1 if dis5==1 & (u15_06a=="c"|u15_06b=="c"|u15_06c=="c"|u15_06d=="c"|u15_06e=="c"|u15_06f=="c"|u15_06g=="c"|u15_06h=="c"|u15_06i=="c"|u15_06j=="c"|u15_06k=="c"|u15_06l=="c"|u15_06m=="c")
label variable dis6c "Battery powered radio"

* dis6d.  What supplies do you have?  (% first aid kit)
gen dis6d = 0 if dis5==1&(v15_06d!=1 & v15_06d!=98 & v15_06d!=.)
replace dis6d = 0 if dis5==1
replace dis6d = 1 if dis5==1&v15_06d==1
replace dis6d = 1 if dis5==1 & (u15_06a=="d"|u15_06b=="d"|u15_06c=="d"|u15_06d=="d"|u15_06e=="d"|u15_06f=="d"|u15_06g=="d"|u15_06h=="d"|u15_06i=="d"|u15_06j=="d"|u15_06k=="d"|u15_06l=="d"|u15_06m=="d")
label variable dis6d "First aid kit"

* dis6e.  What supplies do you have?  (% Flashlight)
gen dis6e = 0 if dis5==1&(v15_06e!=1 & v15_06e!=98 & v15_06e!=.)
replace dis6e = 0 if dis5==1
replace dis6e = 1 if dis5==1&v15_06e==1
replace dis6e = 1 if dis5==1 & (u15_06a=="e"|u15_06b=="e"|u15_06c=="e"|u15_06d=="e"|u15_06e=="e"|u15_06f=="e"|u15_06g=="e"|u15_06h=="e"|u15_06i=="e"|u15_06j=="e"|u15_06k=="e"|u15_06l=="e"|u15_06m=="e")
label variable dis6e "Flashlight"

* dis6f.  What supplies do you have?  (% Cash)
gen dis6f = 0 if dis5==1&(v15_06f!=1 & v15_06f!=98 & v15_06f!=.)
replace dis6f = 0 if dis5==1
replace dis6f = 1 if dis5==1&v15_06f==1
replace dis6f = 1 if dis5==1 & (u15_06a=="f"|u15_06b=="f"|u15_06c=="f"|u15_06d=="f"|u15_06e=="f"|u15_06f=="f"|u15_06g=="f"|u15_06h=="f"|u15_06i=="f"|u15_06j=="f"|u15_06k=="f"|u15_06l=="f"|u15_06m=="f")
label variable dis6f "Cash"

* dis6g.  What supplies do you have?  (% Eyeglasses or medicine)
gen dis6g = 0 if dis5==1&(v15_06g!=1 & v15_06g!=98 & v15_06g!=.)
replace dis6g = 0 if dis5==1  
replace dis6g = 1 if dis5==1&v15_06g==1
replace dis6g = 1 if dis5==1 & (u15_06a=="g"|u15_06b=="g"|u15_06c=="g"|u15_06d=="g"|u15_06e=="g"|u15_06f=="g"|u15_06g=="g"|u15_06h=="g"|u15_06i=="g"|u15_06j=="g"|u15_06k=="g"|u15_06l=="g"|u15_06m=="g")
label variable dis6g "Eyeglasses or medicine"

* dis6h.  What supplies do you have?  (% Important documents)
gen dis6h = 0 if dis5==1&(v15_06h!=1 & v15_06h!=98 & v15_06h!=.)
replace dis6h = 0 if dis5==1 
replace dis6h = 1 if dis5==1&v15_06h==1
replace dis6h = 1 if dis5==1 & (u15_06a=="h"|u15_06b=="h"|u15_06c=="h"|u15_06d=="h"|u15_06e=="h"|u15_06f=="h"|u15_06g=="h"|u15_06h=="h"|u15_06i=="h"|u15_06j=="h"|u15_06k=="h"|u15_06l=="h"|u15_06m=="h")
label variable dis6h "Important documents"

* dis6i.  What supplies do you have?  (% Shovel and/or pick)
gen dis6i = 0 if dis5==1&(v15_06i!=1 & v15_06i!=98 & v15_06i!=.)
replace dis6i = 0 if dis5==1 
replace dis6i = 1 if dis5==1&v15_06i==1
replace dis6i = 1 if dis5==1 & (u15_06a=="i"|u15_06b=="i"|u15_06c=="i"|u15_06d=="i"|u15_06e=="i"|u15_06f=="i"|u15_06g=="i"|u15_06h=="i"|u15_06i=="i"|u15_06j=="i"|u15_06k=="i"|u15_06l=="i"|u15_06m=="i")
label variable dis6i "Shovel and/or pick"

* dis6j.  What supplies do you have?  (% Rain clothes)
gen dis6j = 0 if dis5==1&(v15_06j!=1 & v15_06j!=98 & v15_06j!=.)
replace dis6j = 0 if dis5==1  
replace dis6j = 1 if dis5==1&v15_06j==1
replace dis6j = 1 if dis5==1 & (u15_06a=="j"|u15_06b=="j"|u15_06c=="j"|u15_06d=="j"|u15_06e=="j"|u15_06f=="j"|u15_06g=="j"|u15_06h=="j"|u15_06i=="j"|u15_06j=="j"|u15_06k=="j"|u15_06l=="j"|u15_06m=="j")
label variable dis6j "Rain clothes"

* dis6k.  What supplies do you have?  (% Blankets/Sleeping bags)
gen dis6k = 0 if dis5==1&(v15_06k!=1 & v15_06k!=98 & v15_06k!=.)
replace dis6k = 0 if dis5==1  
replace dis6k = 1 if dis5==1&v15_06k==1
replace dis6k = 1 if dis5==1 & (u15_06a=="k"|u15_06b=="k"|u15_06c=="k"|u15_06d=="k"|u15_06e=="k"|u15_06f=="k"|u15_06g=="k"|u15_06h=="k"|u15_06i=="k"|u15_06j=="k"|u15_06k=="k"|u15_06l=="k"|u15_06m=="k")
label variable dis6k "Blankets/Sleeping bags"

* dis6l.  What supplies do you have?  (% Masks)
gen dis6l = 0 if dis5==1&(v15_06l!=1 & v15_06l!=98 & v15_06l!=.)
replace dis6l = 0 if dis5==1 
replace dis6l = 1 if dis5==1&v15_06l==1
replace dis6l = 1 if dis5==1 & (u15_06a=="l"|u15_06b=="l"|u15_06c=="l"|u15_06d=="l"|u15_06e=="l"|u15_06f=="l"|u15_06g=="l"|u15_06h=="l"|u15_06i=="l"|u15_06j=="l"|u15_06k=="l"|u15_06l=="l"|u15_06m=="l")
label variable dis6l "Masks"

* dis6m.  What supplies do you have?  (% Soap/Hand sanitizer)
gen dis6m = 0 if dis5==1&(v15_06m!=1 & v15_06m!=98 & v15_06m!=.)
replace dis6m = 0 if dis5==1  
replace dis6m = 1 if dis5==1&v15_06m==1
replace dis6m = 1 if dis5==1 & (u15_06a=="m"|u15_06b=="m"|u15_06c=="m"|u15_06d=="m"|u15_06e=="m"|u15_06f=="m"|u15_06g=="m"|u15_06h=="m"|u15_06i=="m"|u15_06j=="m"|u15_06k=="m"|u15_06l=="m"|u15_06m=="m")
label variable dis6m "Soap/Hand Sanitizer"

* dis6z.  What supplies do you have?  (% Other)
gen dis6z = 0 if dis5==1&(v15_06z!=1 & v15_06z!=98 & v15_06z!=.)
replace dis6z = 0 if dis5==1  
replace dis6z = 1 if dis5==1&v15_06z==1
replace dis6z = 1 if dis5==1 & u15_06_ot!=""
label variable dis6z "Other"
local vlist1 a b c d e f g h i j k l m z
foreach var of local vlist1 {
replace dis6`var'=0 if dis6`var'==.&dis5!=.
}

* dis7.  Have you and your family members ever spoken about or planned what you would do if a disaster or emergency occurs? (% Yes)
gen dis7 = 0 if (v15_07!=1 & v15_07!=98 & v15_07!=.)
replace dis7 = 0 if (u15_07!=1 & u15_07!=98 & u15_07!=.)
replace dis7 = 1 if v15_07==1
replace dis7 = 1 if u15_07==1
label variable dis7 "Any discussion of strategies"

* dis8a.  What did you discuss?  (% Planned meeting place)
gen dis8a = 0 if v15_07==1 & (v15_08a!=1 & v15_08a!=98 & v15_08a!=.)
replace dis8a = 0 if u15_07==1 
replace dis8a = 1 if v15_07==1 & v15_08a==1
replace dis8a = 1 if u15_07==1 & (u15_08a=="a"|u15_08b=="a"|u15_08c=="a"|u15_08d=="a"|u15_08e=="a"|u15_08f=="a"|u15_08g=="a"|u15_08h=="a")
label variable dis8a "Planned meeting place"

* dis8b.  What did you discuss?  (% List of important phone numbers)
gen dis8b = 0 if v15_07==1 & (v15_08b!=1 & v15_08b!=98 & v15_08b!=.)
replace dis8b = 0 if u15_07==1 
replace dis8b = 1 if v15_07==1 & v15_08b==1
replace dis8b = 1 if u15_07==1 & (u15_08a=="b"|u15_08b=="b"|u15_08c=="b"|u15_08d=="b"|u15_08e=="b"|u15_08f=="b"|u15_08g=="b"|u15_08h=="b")
label variable dis8b "List of important phone numbers"

* dis8c.  What did you discuss?  (% Measures to strenghten home)
gen dis8c = 0 if v15_07==1 & (v15_08c!=1 & v15_08c!=98 & v15_08c!=.)
replace dis8c = 0 if u15_07==1  
replace dis8c = 1 if v15_07==1 & v15_08c==1
replace dis8c = 1 if u15_07==1 & (u15_08a=="c"|u15_08b=="c"|u15_08c=="c"|u15_08d=="c"|u15_08e=="c"|u15_08f=="c"|u15_08g=="c"|u15_08h=="c")
label variable dis8c "Measures to strenghten home"

* dis8d.  What did you discuss?  (% Emergency suppliers)
gen dis8d = 0 if v15_07==1 & (v15_08d!=1 & v15_08d!=98 & v15_08d!=.)
replace dis8d = 0 if u15_07==1  
replace dis8d = 1 if v15_07==1 & v15_08d==1
replace dis8d = 1 if u15_07==1 & (u15_08a=="d"|u15_08b=="d"|u15_08c=="d"|u15_08d=="d"|u15_08e=="d"|u15_08f=="d"|u15_08g=="d"|u15_08h=="d")
label variable dis8d "Emergency suppliers"

* dis8e.  What did you discuss?  (% Measures of members with special needs)
gen dis8e = 0 if v15_07==1 & (v15_08e!=1 & v15_08e!=98 & v15_08e!=.)
replace dis8e = 0 if u15_07==1  
replace dis8e = 1 if v15_07==1 & v15_08e==1
replace dis8e = 1 if u15_07==1 & (u15_08a=="e"|u15_08b=="e"|u15_08c=="e"|u15_08d=="e"|u15_08e=="e"|u15_08f=="e"|u15_08g=="e"|u15_08h=="e")
label variable dis8e "Measures of members with special needs"

* dis8f.  What did you discuss?  (% Community warning signals)
gen dis8f = 0 if v15_07==1 & (v15_08f!=1 & v15_08f!=98 & v15_08f!=.)
replace dis8f = 0 if u15_07==1  
replace dis8f = 1 if v15_07==1 & v15_08f==1
replace dis8f = 1 if u15_07==1 & (u15_08a=="f"|u15_08b=="f"|u15_08c=="f"|u15_08d=="f"|u15_08e=="f"|u15_08f=="f"|u15_08g=="f"|u15_08h=="f")
label variable dis8f "Community warning signals"

* dis8g.  What did you discuss?  (% Escape and evacuation plans)
gen dis8g = 0 if v15_07==1 & (v15_08g!=1 & v15_08g!=98 & v15_08g!=.)
replace dis8g = 0 if u15_07==1  
replace dis8g = 1 if v15_07==1 & v15_08g==1
replace dis8g = 1 if u15_07==1 & (u15_08a=="g"|u15_08b=="g"|u15_08c=="g"|u15_08d=="g"|u15_08e=="g"|u15_08f=="g"|u15_08g=="g"|u15_08h=="g")
label variable dis8g "Escape and evacuation plans"

* dis8h.  What did you discuss?  (% Going to a shelter)
gen dis8h = 0 if v15_07==1 & (v15_08h!=1 & v15_08h!=98 & v15_08h!=.)
replace dis8h = 0 if u15_07==1  
replace dis8h = 1 if v15_07==1 & v15_08h==1
replace dis8h = 1 if u15_07==1 & (u15_08a=="h"|u15_08b=="h"|u15_08c=="h"|u15_08d=="h"|u15_08e=="h"|u15_08f=="h"|u15_08g=="h"|u15_08h=="h")
label variable dis8h "Going to a shelter"

* dis8z.  What did you discuss?  (% Other)
gen dis8z = 0 if v15_07==1 & (v15_08z!=1 & v15_08z!=98 & v15_08z!=.)
replace dis8z = 0 if u15_07==1  
replace dis8z = 1 if v15_07==1 & v15_08z==1
replace dis8z = 1 if u15_07==1 & u15_08_ot!=""
label variable dis8z "Other"

* dis9a. Compared to just before the pandemic, do you feel like your household is more prepared, equally prepared, or less prepared to handle a disaster or emergency?  (% More prepared)
gen dis9a = 0 if (v15_09!=1 & v15_09!=98 & v15_09!=.)
replace dis9a = 0 if (u15_09!=1 & u15_09!=98 & u15_09!=.)
replace dis9a = 1 if v15_09==1
replace dis9a = 1 if u15_09==1
label variable dis9a "More prepared"
local vlist2 a b c d e f g h z
foreach var of local vlist2 {
replace dis8`var'=0 if dis8`var'==.&dis7!=.
}

* dis9b. Compared to just before the pandemic, do you feel like your household is more prepared, equally prepared, or less prepared to handle a disaster or emergency?  (% Equally prepared)
gen dis9b = 0 if (v15_09!=2 & v15_09!=98 & v15_09!=.)
replace dis9b = 0 if (u15_09!=2 & u15_09!=98 & u15_09!=.)
replace dis9b = 1 if v15_09==2
replace dis9b = 1 if u15_09==2
label variable dis9b "Equally prepared"

* dis9c. Compared to just before the pandemic, do you feel like your household is more prepared, equally prepared, or less prepared to handle a disaster or emergency?  (% Less prepared)
gen dis9c = 0 if (v15_09!=3 & v15_09!=98 & v15_09!=.)
replace dis9c = 0 if (u15_09!=3 & u15_09!=98 & u15_09!=.)
replace dis9c = 1 if v15_09==3
replace dis9c = 1 if u15_09==3
label variable dis9c "Less prepared"

* dis11. Does your community have an early warning system to monitor natural hazards, detect risks, and inform community members about impending threats? (% Yes)
gen dis11 = 0 if (v15_11!=1 & v15_11!=98 & v15_11!=.)
replace dis11 = 0 if (u15_11!=1 & u15_11!=98 & u15_11!=.)
replace dis11 = 1 if v15_11==1
replace dis11 = 1 if u15_11==1
label variable dis11 "Early warning system"

* dis12a. Does your community have A disaster response or emergency plan?  (% Yes)
gen dis12a = 0 if (v15_12a!=1 & v15_12a!=98 & v15_12a!=.)
replace dis12a = 0 if (u15_12a!=1 & u15_12a!=98 & u15_12a!=.)
replace dis12a = 1 if v15_12a==1
replace dis12a = 1 if u15_12a==1
label variable dis12a "Disaster response or emergency plan"

* dis12b. Does your community have A committee or organized group that decides what to do in disasters or emergencies? (% Yes)
gen dis12b = 0 if (v15_12b!=1 & v15_12b!=98 & v15_12b!=.)
replace dis12b = 0 if (u15_12b!=1 & u15_12b!=98 & u15_12b!=.)
replace dis12b = 1 if v15_12b==1
replace dis12b = 1 if u15_12b==1
label variable dis12b "Committee or organized group"

* dis12c. Does your community have Trained community members to assist others in the event of a disaster? (% Yes)
gen dis12c = 0 if (v15_12c!=1 & v15_12c!=98 & v15_12c!=.)
replace dis12c = 0 if (u15_12c!=1 & u15_12c!=98 & u15_12c!=.)
replace dis12c = 1 if v15_12c==1
replace dis12c = 1 if u15_12c==1
label variable dis12c "Trained community members"

* dis12d. Does your community have Evacuation routes?  (% Yes)
gen dis12d = 0 if (v15_12d!=1 & v15_12d!=98 & v15_12d!=.)
replace dis12d = 0 if (u15_12d!=1 & u15_12d!=98 & u15_12d!=.)
replace dis12d = 1 if v15_12d==1
replace dis12d = 1 if u15_12d==1
label variable dis12d "Evacuation routes"

* dis12e. Does your community have A shelter identified where people can go in the event of a disaster?   (% Yes)
gen dis12e = 0 if (v15_12e!=1 & v15_12e!=98 & v15_12e!=.)
replace dis12e = 0 if (u15_12e!=1 & u15_12e!=98 & u15_12e!=.)
replace dis12e = 1 if v15_12e==1
replace dis12e = 1 if u15_12e==1
label variable dis12e "Shelter"

*Percentage of HH perceiving at least one threat (FIGURE 1) and at least two threats
egen sumr = rowtotal(dis3a dis3b dis3c dis3d dis3e dis3f dis3g dis3h dis3i dis3j dis3k dis3l dis3m)
gen onethreat=0
replace onethreat=1 if sumr>0
replace onethreat=. if (dis3a==.&dis3b==.&dis3c==.&dis3d==.&dis3e==.&dis3f==.&dis3g==.&dis3h==.&dis3i==.&dis3j==.&dis3k==.&dis3l==.&dis3m==.)
label variable onethreat "At least one threat"

*Households whose community has a DR system [DRM.Q11-12]
gen any_dr=0
replace any_dr=. if dis11==.&dis12a==.&dis12b==.&dis12c==.&dis12d==.&dis12e==.
replace any_dr=1 if dis11==1|dis12a==1|dis12b==1|dis12c==1|dis12d==1|dis12e==1
label variable any_dr "HH lives in a community with DRM system"

/*================================================
     RECODING SELECTED CONTROL VARIABLES
==================================================*/

*bas1a. What is your relationship with the head of the household? (% Head of Household)
replace v03_01=x03_01 if (v03_00a==1|v03_00b==1)
gen bas1a = 0 if v03_01!=1 & v03_01!=.
replace bas1a = 0 if u03_01!=1 & u03_01!=.
replace bas1a = 1 if v03_01==1
replace bas1a = 1 if u03_01==1

*bas4. Informant's sex? (% Male)
replace v03_04=x03_04 if tipo_muestra==2
gen bas4 = 0 if v03_04==2
replace bas4 = 0 if u03_04==2
replace bas4 = 1 if v03_04==1
replace bas4 = 1 if u03_04==1

*bas9a. What is the highest level of education that you completed? (% None/No education)
replace v03_09a=x03_09a if tipo_muestra==2 & !inlist(v03_09a, 75898,50198,76798,87698,26898,50999)
gen bas9a = 0 if !inlist(v03_09a, 75898,50198,76798,87698,26898,50999)
replace bas9a = 0 if u03_09a!=59701 & u03_09a!=59702 & u03_09a!=.
replace bas9a = 1 if inlist(v03_09a, 75801,50101,76701,59201,59202,87601,87602,26801)|inrange(v03_09a, 50901, 50905)
replace bas9a = 1 if (u03_09a==59701|u03_09a==59702)

*bas9b. What is the highest level of education that you completed? (% Primary)
gen bas9b = 0 if !inlist(v03_09a, 75898,50198,76798,87698,26898,50999)
replace bas9b = 0 if u03_09a!=59703 & u03_09a!=.
replace bas9b = 1 if inlist(v03_09a, 75802,50102,76702,59203,87603,26802)|inrange(v03_09a, 50906, 50911)
replace bas9b = 1 if u03_09a==59703

*bas9c. What is the highest level of education that you completed? (% Secondary)
gen bas9c = 0 if !inlist(v03_09a, 75898,50198,76798,87698,26898,50999)
replace bas9c = 0 if u03_09a!=59704 & u03_09a!=59705 & u03_09a!=.
replace bas9c = 1 if inlist(v03_09a, 75803,50103,76703,59204,87604,26803)|inrange(v03_09a, 50912, 50915)
replace bas9c = 1 if (u03_09a==59704|u03_09a==59705)

*bas9d. What is the highest level of education that you completed? (% Tertiary or more)
gen bas9d = 0 if !inlist(v03_09a, 75898,50198,76798,87698,26898,50999)
replace bas9d = 0 if u03_09a!=59706 & u03_09a!=.
replace bas9d = 1 if inlist(v03_09a, 75804,75805,75806,75807,50104,50105,50106,50107,50108,76704,76705,76706,76707,59205,59206,59207,59208,87605,87606,87607,87608,26804,26805,26806,26807)|inrange(v03_09a, 50916, 50920)
replace bas9d = 1 if u03_09a==59706

*bas10a. What is the highest level of education completed by the head of household? (% None/No education)
replace v03_10a=x03_10a if tipo_muestra==2 & !inlist(v03_10a, 75898,50198,76798,87698,26898,50999)
gen bas10a = 0 if bas1a==0 & !inlist(v03_10a, 75898,50198,76798,87698,26898,50999)
replace bas10a = 0 if u03_01!=. & u03_10a!=59701 & u03_10a!=59702
replace bas10a = 1 if bas1a==0 & inlist(v03_10a, 75801,50101,76701,59201,59202,87601,87602,26801)|inrange(v03_10a, 50901, 50905)
replace bas10a = 1 if u03_01!=. & (u03_10a==59701|u03_10a==59702)

*bas10b. What is the highest level of education completed by the head of household? (% Primary)
gen bas10b = 0 if bas1a==0 & !inlist(v03_10a, 75898,50198,76798,87698,26898,50999)
replace bas10b = 0 if u03_01!=. & u03_10a!=59703
replace bas10b = 1 if bas1a==0 & inlist(v03_10a, 75802,50102,76702,59203,87603,26802)|inrange(v03_10a, 50906, 50911)
replace bas10b = 1 if u03_01!=. & u03_10a==59703

*bas10c. What is the highest level of education completed by the head of household? (% Secondary)
gen bas10c = 0 if bas1a==0 & !inlist(v03_10a, 75898,50198,76798,87698,26898,50999)
replace bas10c = 0 if u03_01!=. & u03_10a!=59704 & u03_10a!=59705
replace bas10c = 1 if bas1a==0 & inlist(v03_10a, 75803,50103,76703,59204,87604,26803)|inrange(v03_10a, 50912, 50915)
replace bas10c = 1 if u03_01!=. & (u03_10a==59704|u03_10a==59705)

*bas10d. What is the highest level of education completed by the head of household? (% Tertiary or more)
gen bas10d = 0 if bas1a==0 & !inlist(v03_10a, 75898,50198,76798,87698,26898,50999)
replace bas10d = 0 if u03_01!=. & u03_10a!=59706
replace bas10d = 1 if bas1a==0 & inlist(v03_10a, 75804,75805,75806,75807,50104,50105,50106,50107,50108,76704,76705,76706,76707,59205,59206,59207,59208,87605,87606,87607,87608,26804,26805,26806,26807)|inrange(v03_10a, 50916, 50920)
replace bas10d = 1 if u03_01!=. & u03_10a==59706

*Education of the respondent
gen school = 1 if bas9a==1|bas9b==1
replace school = 2 if bas9c==1
replace school = 3 if bas9d==1
lab def school 1 "No Educ-Kinder-Primary" 2 "Secondary" 3 "Tertiary or more"
lab val school school

*Education of the head of household
gen school_hh=1 if bas10a==1|bas10b==1
replace school_hh = 2 if bas10c==1
replace school_hh = 3 if bas10d==1
replace school_hh = school if v03_01==1
replace school_hh = school if u03_01==1
lab def school_hh 1 "No Educ-Kinder-Primary" 2 "Secondary" 3 "Tertiary or more"
lab val school_hh school_hh
label variable school_hh "Education of HH"

*bas12. Sex of head of household? (% Male)
gen bas12 = 0 if v03_01!=. & v03_10d==2
replace bas12 = 0 if u03_01!=. & u03_10d==2
replace bas12 = 1 if v03_01!=. & v03_10d==1
replace bas12 = 1 if u03_01!=. & u03_10d==1

*Sex of the repondent
gen sex = v03_04
replace sex = u03_04 if v03_04==.
lab def sex 1 "Male" 2 "Female"
lab val sex sex

*Sex of the head of household
gen sex_hh=bas12
replace sex_hh=v03_04 if v03_01==1
replace sex_hh=u03_04 if u03_01==1
recode sex_hh 0=2
lab def sex_hh 1 "Male" 2 "Female"
lab val sex_hh sex_hh
label variable sex_hh "Sex of HH"

* ind1. Counting all household members, including newborns and older adults, how many people, including yourself, make up your household? (Average)
replace v07_01=x07_01 if v07_00a==2
gen ind1 = v07_01 if v07_01!=99 & v07_01!=.
replace ind1 = u07_01 if u07_01!=99 & u07_01!=.

* ind4. How many of them are 65 and over? (Average)
gen ind4 = v07_04 if ind1!=. & v07_04!=99 & v07_04!=.
replace ind4 = u07_04 if u07_04!=99 & u07_04!=.

* HH has at least one person age 65+
gen senior=ind4
replace senior=1 if ind4>0
label variable senior "HH has at least 1 senior"

* HH has at least one person below 18
gen child=num_hijos
replace child=1 if num_hijos>0
label variable child "HH has at least 1 child"

*inc18a. In your opinion, how much does a home like yours need to cover your basic needs, per month? 
gen inc18a = v06_18a if v06_18a!=.&v06_18a>-1&v06_18a<100000001
replace inc18a = u06_18a if u06_18a!=.&u06_18a>-1&u06_18a<100000001

*inc18b. Does your household currently have 6.18a to cover the cost of basic necessities?
gen inc18b = 0 if inc18a!=. & v06_18b==2
replace inc18b = 0 if inc18a!=. & u06_18b==2
replace inc18b=1 if inc18a!=. & v06_18b==1 
replace inc18b=1 if inc18a!=. & u06_18b==1 

*inc18c. Does your household currently have [40% percentile], to cover the cost of basic necessities??
gen inc18c = 0 if v06_18c==2
replace inc18c = 0 if u06_18c==2
replace inc18c=1 if v06_18c==1 
replace inc18c=1 if u06_18c==1 

* The household can meet monthly basic needs (based on self-determined or predetermined amount)
gen inc18d = inc18b
replace inc18d=inc18c if inc18b==.
label variable inc18d "HH can meet basic needs"

*Locale of the household
gen locale = v03_08
replace locale = u03_08 if v03_08==.
lab def locale 1 "Urban" 2 "Rural"
lab val locale locale
label variable locale "Locale of HH"

* ----------- *
* TABULATION  *
* ----------- *
*Figure 2. Self-reported exposure to disaster risks, household (%)
tabstat onethreat dis3a dis3b dis3c dis3d dis3e dis3f dis3g dis3h dis3i dis3j dis3k dis3l dis3m [aweight = w_hh], by(pais)

*Figure 3. Factors contributing to ability to cope with disasters, household (%)
tabstat dis5 dis7 any_dr[aw = w_hh], by(pais) 

*Figure 4. Preparedness to cope with a disaster, household (%)
estpost tabstat dis4* [aw = w_hh], by(pais)

*Figure 5. Change in preparedness to cope with a disaster or emergency after COVID-19, household (%)
tabstat dis9* [aw = w_hh], by(pais)

*Table 1. Descriptive statistics of household socioeconomic characteristics
by pais, sort : summarize ib1.sex_hh ib1.school_hh ib2.locale child senior inc18d [aweight = w_hh]

*Table 2. Aspects of factors that contribute to disaster risk preparedness (means in percentages)
tabstat dis5 dis6* dis7 dis8* any_dr dis12* [aw = w_hh], by(pais)

*Table 3. Socio-demographic correlates of factors that contribute to ability to cope with disasters (OLS weighted)
global depv dis5 dis7 any_dr
local is_first_iteration 1
foreach y of global depv {
  foreach x in 509 597 501 767 758 {
    reg `y' ib1.sex_hh ib1.school_hh ib2.locale child senior inc18d [aw = w_hh] if pais == `x'
      if `is_first_iteration' {
      outreg2 using Table3.xls, replace dec(2) e(F r2_p)
      local is_first_iteration 0
			} 
		else {
        outreg2 using Table3.xls, append dec(2) e(F r2_p)
        }
    }
}

*Table 4. Factors that may contribute to ability to cope with disasters (OLS weighted)
local is_first_iteration 1
foreach x in 509 597 501 767 758 {
reg prepared dis5 dis7 any_dr [aw = w_hh] if pais==`x'
      if `is_first_iteration' {
      outreg2 using Table4.xls, replace dec(2) e(F r2_p)
      local is_first_iteration 0
			} 
		else {
        outreg2 using Table4.xls, append dec(2) e(F r2_p)
        }
    }

*Table A2.1. Socio-demographic correlates of preparedness to cope with a disaster
local is_first_iteration 1
foreach x in 509 597 501 767 758 {
reg prepared ib1.sex_hh ib1.school_hh ib2.locale child senior inc18d [aw = w_hh] if pais==`x'
      if `is_first_iteration' {
      outreg2 using TableA21.xls, replace dec(2) e(F r2_p)
      local is_first_iteration 0
			} 
		else {
        outreg2 using TableA21.xls, append dec(2) e(F r2_p)
        }
    }